.. figure:: https://raw.github.com/ChrisCummins/labm8/master/.labm8.jpg
   :alt: labm8

|Build Status| |Coverage Status| |Documentation Status| |PyPi Status| |Python Version| |License Badge|

::

    $ pip install labm8

Supports Python versions 2.7 and >= 3.4.

Copyright 2015, 2016 Chris Cummins <chrisc.101@gmail.com>.

Released under the terms of the GPLv3 license. See
`LICENSE.txt </LICENSE.txt>`__ for details.

.. |Build Status| image:: https://img.shields.io/travis/ChrisCummins/labm8/master.svg?style=flat
   :target: https://travis-ci.org/ChrisCummins/labm8

.. |Coverage Status| image:: https://img.shields.io/coveralls/ChrisCummins/labm8/master.svg?style=flat
   :target: https://coveralls.io/github/ChrisCummins/labm8?branch=master

.. |Documentation Status| image:: https://readthedocs.org/projects/labm8/badge/?version=latest&style=flat
   :target: http://labm8.readthedocs.io/en/latest/?badge=latest

.. |PyPi Status| image:: https://badge.fury.io/py/labm8.svg
   :target: https://pypi.python.org/pypi/labm8

.. |Python Version| image:: https://img.shields.io/badge/python-2%20%26%203-blue.svg?style=flat
   :target: https://www.python.org/

.. |License Badge| image:: https://img.shields.io/badge/license-GNU%20GPL%20v3-blue.svg?style=flat
   :target: https://www.gnu.org/licenses/gpl-3.0.en.html
